JsonTreeView class

Inheritance

Constructors

JsonTreeView(dynamic json, {Key? key, JsonStyle? style, int initialExpandedDepth = 0, Widget loadingBuilder(BuildContext context)?, Widget errorBuilder(BuildContext context, Object error, StackTrace stackTrace)?, JsonWidgetBuilder widgetBuilder = const JsonWidgetBuilder(), ValueChanged<JsonNode>? onNodeTap, ValueChanged<JsonNode>? onNodeLongTap})
const

Properties

errorBuilder Widget Function(BuildContext context, Object error, StackTrace stackTrace)?
final
hashCode int
The hash code for this object.
no setterinherited
initialExpandedDepth int
final
json → dynamic
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingBuilder Widget Function(BuildContext context)?
final
onNodeLongTap ValueChanged<JsonNode>?
final
onNodeTap ValueChanged<JsonNode>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style JsonStyle?
final
widgetBuilder JsonWidgetBuilder
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<JsonTreeView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited