ObjectNode class

Inheritance
Mixed-in types

Constructors

ObjectNode({required String? key, required List<JsonNode> value, required int index, required int depth, bool isExpanded = false})

Properties

depth int
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
index int
finalinherited
isExpanded bool
getter/setter pair
key String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value List<JsonNode>
finalinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited